Learn R Programming

IRISMustangMetrics (version 1.0.0)

STALTAMetric: Maximum STA/LTA of a signal

Description

The STALTAMetric() function calculates the maximum of STA/LTA over the incoming seismic signal.

Usage

STALTAMetric(st, staSecs, ltaSecs, increment, algorithm)

Arguments

st
a Stream object containing a seismic signal
staSecs
length of the Short averaging window in secs (default=3)
ltaSecs
length of the Long averaging windowin secs (default=30)
algorithm
algorithm to be used (default="classic_LR")
increment
increment used when sliding the averaging windows to the next location (default=1)

Value

  • A list with a single SingleValueMetric object is returned. The metric name is max_stalta.

code

STALTA.Trace()

itemize

  • demean=TRUE

item

  • detrend=TRUE
  • taper=0.0

Details

Currently supported algorithms include:

  • "classic_RR"
"classic_LR" "EarleAndShearer_envelope"

References

http://en.wikipedia.org/wiki/First_break_picking{First break picking} (Wikipedia)

http://www.crewes.org/ForOurSponsors/ConferenceAbstracts/2009/CSEG/Wong_CSEG_2009.pdf{Automatic time-picking of first arrivals on noisy microseismic data} (Wong et. al. 2009)

http://www.fcaglp.unlp.edu.ar/~velis/papers/PickingGeop10.pdf{Automatic first-breaks picking: New strategies and algorithms} (Sabbione and Velis 2010) )

Examples

Run this code
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient")

# Get the waveform
starttime <- as.POSIXct("2012-02-12",tz="GMT")
endtime <- as.POSIXct("2012-02-13",tz="GMT")
st <- getDataselect(iris,"AK","GHO","","BHN",starttime,endtime)

# Calculate the STA/LTA metric and show the results
metricList <- STALTAMetric(st)
dummy <- lapply(metricList, show)

Run the code above in your browser using DataLab