Learn R Programming

IRISMustangMetrics (version 1.0.0)

SingleValueMetric-class: Class "SingleValueMetric"

Description

A container for metrics results and associated metadata. This information is used to create XML that is then submitted to the MUSTANG Backend Storage System (BSS).

Arguments

Objects from the Class

Objects can be created by calls of the form:

new("SingleValueMetric", snclq, starttime, endtime, metricName, value)

Lists of SingleValueMetric objects are returned by various metrics functions in this package.

Examples

Run this code
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient")

# Get the waveform
starttime <- as.POSIXct("2012-01-24", tz="GMT")
endtime <- as.POSIXct("2012-01-25", tz="GMT")
st <- getDataselect(iris,"AK","PIN","","VEA",starttime,endtime)

# Apply a metric and show the results
metricList <- basicStatsMetric(st)
show(metricList[[1]])

Run the code above in your browser using DataLab