Learn R Programming

IRISMustangMetrics (version 1.0.0)

convertBssErrors: Generate Human Readable MUSTANG Errors

Description

The MUSTANG database is in charge of storing the results of metrics calculations and is accessed through a webservice API. TheconvertBssErrors function extracts pertinent error information from the HTML returned by MUSTANG on error conditions.

Usage

convertBssErrors(err_msg)

Arguments

err_msg
error text received from the MUSTANG

Value

  • Aext string with the root cause extracted from the MUSTANG HTML Java error dump.

See Also

SingleValueMetric-class, metricList2Xml, getMetricsXml, getBssMetricList,