Learn R Programming

IRISMustangMetrics (version 1.0.0)

gapsMetric: Gaps and overlaps in a signal

Description

The gapsMetric() function calculates metrics associated with gaps and overlaps in a siesmic signal, i.e. when st consists of more than one Trace.

Usage

gapsMetric(st)

Arguments

st
a Stream object containing a seismic signal

Value

  • A list of SingleValueMetric objects is returned.

Details

This function uses the output of the getGaps method of Stream objects to calculate the following metrics: [object Object],[object Object],[object Object],[object Object],[object Object] The requestedStarttime and requestedEndtime slots for the Stream are used to determine gaps before the start of the firstor after the end of the last Trace in the Stream.

Examples

Run this code
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient")

# Get the waveform
starttime <- as.POSIXct("2012-01-24", tz="GMT")
endtime <- as.POSIXct("2012-01-25", tz="GMT")
st <- getDataselect(iris,"AK","PIN","","VEA",starttime,endtime)

# Calculate the gaps metrics and show the results
metricList <- gapsMetric(st)
dummy <- lapply(metricList, show)

Run the code above in your browser using DataLab