Learn R Programming

IRISMustangMetrics (version 1.0.1)

getBssMetricList: Retrieve measurements XML from the MUSTANG BSS and convert them to a metricList

Description

The getBssMetricList method makes a request of the MUSTANG BSS (Backend Storage System) and returns a list of _Metric objects.

Usage

getBssMetricList(obj, network, station, location, channel, starttime, endtime, metricName, url)

Arguments

obj
an IrisClient object
network
a character string with the two letter seismic network code
station
a character string with the station code
location
a character string with the location code
channel
a character string with the three letter channel code
starttime
a POSIXct class specifying the starttime (GMT)
endtime
a POSIXct class specifying the endtime (GMT)
metricName
a character string identifying the name of the metric stored in the BSS
url
optional url of the BSS measurements service

Value

A list of _Metric objects is returned.

Details

This method calls on getMetricsXml to communicate with the BSS and obtain an XML reponse. This response is then processed and used to create _Metric objects which are returned as a metricList.

Error returns from the BSS will stop evaluation and throw an error message.

See Also

getMetricsXml

Examples

Run this code
  ## Not run: 
# # Open a connection to IRIS DMC webservices (including the BSS)
# iris <- new("IrisClient", debug=TRUE)
# 
# starttime <- as.POSIXct("2012-01-24", tz="GMT")
# endtime <- as.POSIXct("2012-01-25", tz="GMT")
# 
# # Get the metricList
# metricList <- getBssMetricList(iris,"AK","PIN","","",starttime,endtime,
#                                metricName="sample_mean")
# show(metricList)
#   ## End(Not run)

Run the code above in your browser using DataLab