Learn R Programming

IRISMustangMetrics (version 1.0.0)

getLatencyValuesXml: Retrieve instantaneous data latency XML from the MUSTANG latency servlet.

Description

The getLatencyValuesXml method makes a request of the IRIS DMC latency servlet and returns the unprocessed data latency XML for submission to the MUSTANG BSS (Backend Storage System).

Usage

getLatencyValuesXml(obj, network, station, location, channel, url)

Arguments

obj
IrisClient object
network
character string with the two letter seismic network code
station
character string with the station code
location
character string with the location code
channel
character string with the three letter channel code
url
optional url of the latency web service

Value

  • An XML string is returned.

Details

Error returns from the webservice will stop evaluation and throw an error message.

See Also

IrisClient-class