Learn R Programming

IRISMustangMetrics (version 1.0.1)

metricList2DFList: Conver a metricList into a list of dataframes

Description

The metricList2DFList function converts a list of SingleValueMetrics into a list of dataframes, one per named metric.

Usage

metricList2DFList(metricList)

Arguments

metricList
a list of SingleValueMetric objects

Value

A character string with BSS formatted XML is returned.

Details

Metrics functions return lists of SingleValueMetric objects. A long metricList may be built up by appending the results of different metrics functions or the same metrics function operating on different seismic signals. A metricList generated by any of the MUSTANG Rscripts can be stored as an .RData file and reloaded for examination.

A metricList may contain values for many different metrics. This function creates a separate dataframe for each metricName found in the metricList. As each dataframe is created, values associated with that metric are stored in a column named after the metric. Individual dataframes are stored in the returned list with their own name: metricName_DF.

See Also

SingleValueMetric-class, metricList2Xml

Examples

Run this code
  ## Not run: 
# load('metricList_3756.RData')
# dfList <- metricList2DFList(metricList)
# names(dfList)
# [1] "peak_correlation_DF" "peak_lag_DF"        
# corr <- dfList[["peak_correlation_DF"]]
# names(corr)
# [1] "snclq"                "starttime"            "endtime"              "attributeName"       
# [5] "attributeValueString" "quality_flag"         "peak_correlation"    
#   ## End(Not run)

Run the code above in your browser using DataLab