Learn R Programming

IRISMustangMetrics (version 1.0.0)

seismicMetrics-package: Utilities for calculating seismic metrics from IRIS DMC data

Description

This package provides S4 classes and functions for calculating metrics from seismological data available from the IRIS Data Management Center (DMC) (http://www.iris.edu/dms/nodes/dmc/). This package is part of the MUSTANG project and is intended for DMC internal use only.

Arguments

Introduction

The seismicMetrics package depends upon the seismic package which defines new S4 classes and methods for manipulating seismic data. Please see the "seismic-intro" vignette for introductory examples on using seismic.

History

version 1.0.0 -- First Public Release

References

IRIS DMC web services: http://service.iris.edu/

Examples

Run this code
# Open a connection to IRIS DMC webservices
iris <- new("IrisClient", debug=TRUE)

# Get the seismic data
starttime <- as.POSIXct("2010-02-27 06:45:00",tz="GMT")
endtime <- as.POSIXct("2010-02-27 07:45:00",tz="GMT")
st <- getDataselect(iris,"IU","ANMO","00","BHZ",starttime,endtime)

# Apply a metric and show the results
metricList <- basicStatsMetric(st)
dummy <- lapply(metricList, show)

Run the code above in your browser using DataLab