## Not run:
# # Open a connection to IRIS DMC webservices
# iris <- new("IrisClient")
#
# # Get a signal with a DC offset problem
# starttime <- as.POSIXct("2012-10-26",tz="GMT")
# endtime <- starttime + 2*24*3600
# st <- getDataselect(iris,"IU","TARA","00","BHZ",starttime,endtime)
#
# # Calculate the metric
# metricList <- DCOffsetTimesMetric(st)
#
# # Extract values from the first element of the list
# offsetTimes <- metricList[[1]]@values
#
# # Plot the signal and mark locations where a DC offset was detected
# plot(st)
# abline(v=offsetTimes,col='red')
# ## End(Not run)
Run the code above in your browser using DataLab